@@ -114,12 +114,13 @@ extern int delserver(char *, int, int, int, int, int);
 extern int deladverts(struct channel *, char *);
 extern int setpassword(struct channel *, char *, char *);
 extern int logoff(struct channel *, char *);
-extern int logon(struct channel *, char *, char *, char *, int);
+extern int logon(struct channel *, struct botuser *, char *, char *, int);
 extern int timed_cmp(struct timed *, struct timed *);
 extern int clonechannel(char *, char *);
 extern int isfriend(struct channel *, char *, char *);
 extern int deltachanflags(struct channel *, char *, char);
 extern int isvalidchannel(char *);
+extern int hasuserflags(struct channel *, char *, char *, char *);
 extern unsigned int getrandom(unsigned int);
 extern struct authed *addnewauthed(struct channel *, time_t, struct botuser *, char *);
 extern struct botuser *addbotuser(char *, char *);
@@ -153,7 +154,6 @@ extern struct chanuser *getrandomuser(struct channel *);
 extern struct ls_wrapstruct *addnew_ls(struct ls_wrapstruct *, int, time_t, char *, char *, char *);
 extern struct timed *timed_new(struct channel *, time_t, int, int, char *);
 extern struct mmode *mmode_new(struct channel *, time_t, char *, char *);
-extern struct botuser *hasuserflags(struct channel *, char *, char *);
 extern time_t lastoff(struct channel *, char *, char *);
 extern void sendadverts(struct channel *, char *, char *);
 extern void resetparts(struct channel *, char *, char *);
@@ -202,7 +202,7 @@ extern void syncuserhosts(void);
 extern void settopic(struct channel *);
 extern void processenv(void);
 extern void processnetjoin(struct channel *);
-extern void mmodes2timeds(struct channel *);
+extern void mmodes2timeds(void);
 extern void processlock(struct channel *);
 extern void joinchannel(struct channel *);
 extern void updatelast(struct channel *, char *, char *, char *);
