@@ -492,6 +492,10 @@ int processtimeds()
 		if(actions >= OER_ACTIONS_PER_MAINLOOP) {
 			return OER_PROCESSTIMEDS_EVERYTHING_OK;
 		}
+		/* limit kicks */
+		if(t1->type == OER_TIMED_TYPE_KICK && actions >= OER_KICKS_PER_MAINLOOP) {
+			return OER_PROCESSTIMEDS_EVERYTHING_OK;
+		}
 		got_timed = 0;
 		switch(t1->type) {
 		case OER_TIMED_TYPE_KICK:
