@@ -255,6 +255,9 @@ int main(int argc, char *argv[])
 		if(mystate->now <= mystate->last_actions) {
 			continue;
 		}
+		/* convert all mmodes to timeds */
+                mmodes2timeds();
+		/* process timeds */
 		switch(processtimeds()) {
 		case OER_PROCESSTIMEDS_ERR_WRITE:
 			mystate->reconnect = OER_RECONNECT_ERROR;
