@@ -496,7 +496,7 @@ void parseirc(char *serveroutput)
 			if(!gettobek(this, nick) && checkforbadnick(this, nick, userhost)) {
 				changetobek(this, nick, 1);
 			}
-			if(!gettobek(this, nick) && haschanflags(this, "v") && hasuserflags(this, userhost, "v") != NULL) {
+			if(!gettobek(this, nick) && haschanflags(this, "v") && hasuserflags(this, userhost, "v", "")) {
 				mmode_new(this, mystate->now, "+v", nick);
 			}
 			if(!gettobek(this, nick) && haschanflags(this, "O") && isopa(userhost)) {
@@ -517,7 +517,7 @@ void parseirc(char *serveroutput)
 		if(!haschanflags(this, "q")) {
 			return;
 		}
-		if(hasuserflags(this, userhost, "x") != NULL) {
+		if(hasuserflags(this, userhost, "x", "")) {
 			return;
 		}
 		if((mystate->now - this->last_quote) < OER_QUOTE_INTERVAL) {
@@ -1023,7 +1023,7 @@ void parsemsg(char *nick, char *userhost, char *target, char *message)
 #endif
 		return;
 	}
-	if(hasuserflags(this, userhost, "x") != NULL) {
+	if(hasuserflags(this, userhost, "x", "")) {
 		/* user's messages won't be saved */
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsemsg->messages from %s to %s won't be saved\n", nick, target);
@@ -1391,7 +1391,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		if(!isadmin(this, userhost)) {
-			if(hasuserflags(this, userhost, "or") == NULL) {
+			if(!hasuserflags(this, userhost, "or", "")) {
 				return;
 			}
 		}
@@ -1412,7 +1412,7 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 			return;
 		}
 		if(!isadmin(this, userhost)) {
-			if(hasuserflags(this, userhost, "or") == NULL) {
+			if(!hasuserflags(this, userhost, "or", "")) {
 				return;
 			}
 		}
@@ -1935,24 +1935,20 @@ void parsecommand(char *target, char *nick, char *userhost, char *commandline)
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGOFF\n");
 #endif
-		if((this = getchptr(channel)) == NULL) {
-			return;
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
+		this = getchptr(channel);
 		logoffcommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
 		return;
 	case OER_WHICHCOMMAND_LOGON:
 #ifdef DEBUG
 		oer_debug(OER_DEBUG_INFO, "parsecommand->LOGON\n");
 #endif
-		if((this = getchptr(channel)) == NULL) {
-			return;
-		}
 		if(!strlen(restptr)) {
 			return;
 		}
+		this = getchptr(channel);
 		logoncommand(this, (tochan) ? this->name : nick, tochan, nick, userhost, restptr);
 		return;
 	case OER_WHICHCOMMAND_SAVE:
